#line 2 "tnglex.C"

#line 4 "tnglex.C"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

    /* The c++ scanner is a mess. The FlexLexer.h header file relies on the
     * following macro. This is required in order to pass the c++-multiple-scanners
     * test in the regression suite. We get reports that it breaks inheritance.
     * We will address this in a future release of flex, or omit the C++ scanner
     * altogether.
     */
    #define yyFlexLexer tngFlexLexer

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */
#include <iostream> 
#include <errno.h>
#include <cstdlib>
#include <cstring>
/* end standard C++ headers. */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{

	std::istream* yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

void *tngalloc (yy_size_t  );
void *tngrealloc (void *,yy_size_t  );
void tngfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

#define yytext_ptr yytext

#include <FlexLexer.h>

int yyFlexLexer::yywrap() { return 1; }

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 57
#define YY_END_OF_BUFFER 58
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[250] =
    {   0,
        0,    0,    2,    2,   58,   56,   52,   55,   56,   56,
       56,   56,   56,   41,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   56,   56,    2,    1,   52,   53,
        0,   48,    0,   49,    0,   41,   43,   42,   41,    0,
       51,   44,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   29,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   54,    0,   50,    2,
       44,    0,   45,    0,    0,    0,   42,   51,   51,   51,

       51,    5,   51,   51,   51,   51,   51,   51,   51,   51,
       16,   18,   51,   51,   51,   51,   23,   51,   51,   51,
       51,   28,   51,   51,   51,   51,   34,   51,   51,   51,
       51,   51,   51,   42,    0,   43,    0,   51,   51,   51,
        7,   51,    9,   10,   51,   51,   51,   51,   51,    0,
       51,   51,   51,   51,   24,   51,   26,   51,   51,   51,
       51,   51,   51,   51,   37,   51,   51,   51,    0,   46,
        3,   51,    6,   51,   11,   51,   51,   51,   51,    0,
       51,   51,   21,   51,   25,   51,   51,   51,   32,   51,
       51,   51,   51,   39,   51,   47,   46,   51,    8,   51,

       51,   51,   51,    0,   19,   51,   51,   51,   51,   31,
       51,   35,   51,   51,   40,   51,   12,   51,   13,   51,
        0,   51,   51,   27,   51,   33,   51,   38,   51,   14,
       15,   17,   20,   51,   30,   51,   51,   51,   51,    4,
       51,   51,   51,   51,   51,   51,   22,   36,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    1,    1,    1,    1,    6,    1,
        1,    1,    7,    1,    8,    9,    1,   10,   11,   12,
       13,   14,   15,   13,   13,   13,   16,   17,    1,    1,
        1,    1,    1,    1,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   34,
        1,   43,    1,    1,    1,    1,   44,   45,   46,   47,

       48,   49,   50,   51,   52,   53,   54,   55,   56,   57,
       58,   59,   34,   60,   61,   62,   63,   64,   65,   66,
       67,   34,   68,    1,   69,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[70] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    3,    4,
        4,    4,    4,    4,    4,    4,    3,    3,    3,    3,
        4,    4,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    1,    3,    3,    3,    4,    4,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    1,    1
    } ;

static yyconst flex_int16_t yy_base[257] =
    {   0,
        0,    0,  210,  208,  195, 1179,  187, 1179,  164,  155,
      133,   61,   68,   76,   85,   90,   86,   87,   97,  104,
      124,  148,  120,  137,  138,  154,  152,  168,  164,  165,
      170,  193,  182,  199,   87,   58,    0, 1179,  118, 1179,
      111, 1179,  109, 1179,  224,  239,  184,  221,  279,  260,
      171,  205,  321,  208,  293,  302,  300,  248,  298,  288,
      334,  249,  289,  338,  345,  339,  340,  354,  361,  364,
      363,  377,  374,  368,  380,  250,  379,  392,  398,  405,
      402,  395,  421,  425,  430,  426, 1179,   42, 1179,    0,
     1179,  456, 1179,  481,  463,  488,  496,  442,  505,  506,

      507,  268,  508,  510,  521,  522,  523,  525,  527,  528,
      428,  305,  540,  547,  564,  554,  432,  557,  578,  575,
      581,  585,  590,  591,  600,  602,  605,  607,  611,  618,
      628,  621,  623,  660,  680,  687,  695,  637,  632,  703,
      644,  704,  651,  668,  705,  706,  707,  708,  717,   94,
      718,  729,  730,  728,  670,  733,  735,  747,  754,  756,
      759,  760,  772,  773,  774,  786,  792,  785,  812,  835,
      788,  820,  790,  843,  822,  844,  825,  847,  850,  118,
      860,  861,  854,  864,  865,  867,  879,  884,  886,  896,
      893,  897,  900,  902,  909,  923,  949,  934,  907,  933,

      931,  958,  959,  102,  935,  961,  962,  968,  979,  964,
      986,  981,  982,  993,  984, 1002, 1005, 1011, 1012, 1016,
      360, 1025, 1018, 1027, 1032, 1037, 1039, 1042, 1043, 1046,
     1049, 1179, 1053, 1058, 1060, 1063, 1069, 1076, 1079, 1074,
     1080, 1086, 1089, 1095, 1109, 1110, 1096, 1105, 1179, 1156,
     1160, 1164, 1166, 1170, 1174,   96
    } ;

static yyconst flex_int16_t yy_def[257] =
    {   0,
      249,    1,  250,  250,  249,  249,  249,  249,  249,  251,
      252,  249,  249,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  249,  254,  255,  249,  249,  249,
      251,  249,  252,  249,  249,  249,  256,  256,  253,  249,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  249,  254,  249,  255,
      249,  249,  249,  249,  249,  249,  253,  253,  253,  253,

      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  249,  249,  249,  249,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  249,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  249,  249,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  249,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  249,  249,  253,  253,  253,

      253,  253,  253,  249,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      249,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  249,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,    0,  249,
      249,  249,  249,  249,  249,  249
    } ;

static yyconst flex_int16_t yy_nxt[1249] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   12,   13,   14,
       14,   14,   14,   14,   14,   14,    6,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   15,   25,   26,
       15,   27,   28,   15,   29,   30,   31,   15,   32,   33,
       15,   34,   35,   15,   16,   17,   18,   19,   20,   21,
       22,   23,   24,   15,   25,   26,   15,   27,   28,   29,
       30,   31,   15,   32,   33,   15,   34,   36,    6,   45,
       46,   46,   46,   46,   46,   46,   46,   47,   47,   47,
       47,   47,   47,   47,   48,   49,   49,   49,   49,   49,
       49,   49,   50,  249,  249,  249,   52,   53,  249,   47,

       54,  249,  249,  249,   60,  249,  249,   55,   61,  221,
       89,   58,  249,  249,   44,   42,   62,   87,   56,   39,
      249,   57,   52,   53,  180,   63,   89,   59,  249,   64,
       60,   65,  249,   55,   61,   66,  249,   58,   44,   71,
      249,   67,   62,   87,   56,  249,  249,   57,   72,  204,
      180,   63,   59,  249,  249,   64,  249,   65,   68,   42,
      249,   66,  249,   73,  249,   71,   40,   67,  249,   69,
      249,   74,  249,  249,   75,  204,  249,   70,  249,  249,
      249,  249,   76,   68,  249,   80,  249,  249,   39,   73,
      249,   83,   77,   78,  249,   69,   81,   74,  249,   79,

       75,  249,   82,   70,   93,   94,   85,  249,   76,  249,
       38,   80,   38,  249,   84,  249,  249,   83,   77,   78,
       86,  249,   81,   98,  249,   79,  249,   82,  249,  249,
       93,   94,   85,   47,   47,   47,   47,   47,   47,   47,
       84,   91,   92,  249,  249,  249,   86,   48,   46,   46,
       46,   46,   46,   46,   46,   50,  249,  249,  249,   91,
       92,  249,  249,  249,  249,  249,  249,   91,   92,   95,
       95,   95,   95,   95,   95,   95,  249,  108,  249,  249,
      249,  249,  103,  249,  249,   91,   92,   48,   49,   49,
       49,   49,   49,   49,   49,   50,  249,  249,  249,   52,

       53,  249,  249,  108,  249,  249,  249,  103,  249,  249,
      249,  249,   99,  249,  249,  104,  249,  109,  249,  100,
      249,  249,  249,  249,  105,   52,   53,   96,   96,  249,
       97,   97,   97,   97,   97,   97,   97,  249,   99,  101,
      102,  104,  249,  109,  249,  100,  249,  249,  249,  105,
      249,  249,  106,  249,  249,  249,  249,  107,  111,  112,
      249,  249,  249,  249,  101,  102,  110,  249,  114,  249,
      249,  249,  249,  113,  249,  115,  249,  249,  106,  249,
      249,  232,  249,  107,  249,  249,  119,  249,  249,  116,
      249,  121,  110,  249,  114,  249,  249,  118,  113,  117,

      249,  115,  122,  249,  120,  249,  249,  232,  249,  249,
      249,  249,  249,  249,  249,  116,  249,  121,  249,  249,
      123,  249,  118,  125,  117,  127,  126,  129,  122,  249,
      120,  249,  124,  249,  249,  150,  249,  249,  249,  128,
      249,  249,  249,  249,  249,  123,  249,  249,  249,  125,
      249,  127,  126,  129,  133,  132,  138,  124,  249,  131,
      249,  130,   96,   96,  128,  134,  134,  134,  134,  134,
      134,  134,   95,   95,   95,   95,   95,   95,   95,  137,
      133,  132,  249,  249,  131,  249,  130,  135,  135,  249,
      136,  136,  136,  136,  136,  136,  136,  134,  134,  134,

      134,  134,  134,  134,  249,   97,   97,   97,   97,   97,
       97,   97,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  140,  249,  142,  141,  249,
      249,  249,  139,  249,  249,  249,  249,  249,  249,  249,
      143,  249,  144,  249,  249,  249,  249,  249,  249,  149,
      147,  140,  148,  142,  141,  249,  249,  146,  139,  145,
      249,  249,  249,  249,  152,  249,  143,  249,  144,  151,
      249,  249,  249,  249,  249,  149,  147,  249,  148,  154,
      249,  249,  146,  249,  145,  153,  249,  156,  249,  249,
      152,  249,  155,  249,  249,  151,  157,  249,  249,  249,

      249,  249,  158,  249,  249,  154,  249,  249,  249,  249,
      249,  153,  160,  249,  249,  249,  249,  155,  249,  249,
      249,  249,  157,  249,  249,  159,  249,  249,  158,  249,
      161,  249,  164,  249,  249,  249,  249,  249,  160,  249,
      249,  163,  249,  162,  249,  249,  171,  249,  249,  249,
      159,  168,  249,  249,  165,  172,  161,  167,  164,  249,
      249,  249,  249,  166,  249,  249,  163,  249,  162,  134,
      134,  134,  134,  134,  134,  134,  249,  168,  249,  165,
      249,  172,  167,  249,  249,  249,  249,  249,  166,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,

      136,  136,  136,  169,  170,  170,  170,  170,  170,  170,
      170,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  176,  175,  249,
      173,  249,  174,  249,  249,  181,  249,  249,  249,  177,
      178,  249,  185,  249,  249,  249,  249,  179,  182,  249,
      249,  249,  249,  176,  175,  249,  173,  249,  174,  184,
      183,  181,  249,  249,  249,  177,  178,  249,  249,  249,
      249,  249,  249,  179,  182,  249,  249,  186,  249,  187,
      249,  249,  249,  190,  188,  184,  183,  249,  249,  249,
      249,  191,  249,  249,  249,  189,  249,  249,  249,  249,

      249,  249,  249,  186,  249,  187,  249,  192,  249,  190,
      188,  193,  249,  194,  249,  249,  195,  191,  249,  249,
      189,  196,  196,  196,  196,  196,  196,  196,  249,  249,
      249,  249,  192,  249,  249,  249,  249,  193,  249,  194,
      249,  249,  195,  197,  170,  170,  170,  170,  170,  170,
      170,  249,  249,  249,  198,  249,  249,  249,  249,  249,
      249,  201,  249,  249,  199,  200,  249,  203,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  198,
      249,  249,  202,  249,  249,  207,  201,  249,  249,  249,
      199,  200,  249,  203,  249,  249,  205,  206,  209,  249,

      249,  249,  249,  208,  249,  249,  249,  202,  249,  249,
      249,  207,  249,  249,  212,  249,  249,  249,  249,  210,
      213,  205,  206,  249,  209,  249,  249,  211,  208,  249,
      249,  214,  196,  196,  196,  196,  196,  196,  196,  249,
      212,  249,  249,  249,  210,  249,  213,  249,  215,  249,
      249,  249,  249,  211,  249,  249,  218,  214,  196,  196,
      196,  196,  196,  196,  196,  216,  249,  249,  217,  249,
      249,  249,  249,  215,  249,  249,  249,  249,  249,  219,
      249,  223,  218,  249,  249,  224,  222,  249,  220,  249,
      249,  216,  249,  217,  249,  249,  225,  249,  249,  227,

      249,  249,  249,  249,  249,  219,  249,  223,  249,  249,
      249,  224,  222,  249,  220,  249,  226,  249,  249,  249,
      249,  249,  225,  228,  249,  227,  249,  249,  249,  249,
      230,  249,  249,  249,  249,  249,  249,  231,  249,  229,
      249,  249,  226,  249,  233,  249,  234,  249,  249,  228,
      249,  249,  249,  249,  249,  249,  230,  249,  249,  249,
      235,  249,  249,  231,  229,  249,  249,  236,  249,  249,
      233,  249,  234,  237,  249,  249,  249,  249,  249,  249,
      239,  249,  249,  238,  249,  249,  235,  249,  249,  240,
      249,  249,  249,  236,  249,  249,  249,  249,  242,  237,

      249,  249,  249,  249,  249,  249,  239,  249,  241,  238,
      249,  249,  249,  249,  245,  240,  243,  249,  249,  249,
      246,  249,  244,  249,  242,  249,  249,  249,  247,  248,
      249,  249,  249,  249,  241,  249,  249,  249,  249,  249,
      245,  243,  249,  249,  249,  249,  246,  244,  249,  249,
      249,  249,  249,  249,  247,  248,   37,   37,   37,   37,
       41,  249,   41,   41,   43,  249,   43,   43,   51,   51,
       88,  249,   88,   88,   90,  249,   90,   90,    5,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,

      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249
    } ;

static yyconst flex_int16_t yy_chk[1249] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,   12,
       12,   12,   12,   12,   12,   12,   12,   13,   13,   13,
       13,   13,   13,   13,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   15,   17,   18,   14,   14,   16,  256,

       16,   15,   17,   18,   18,   19,   16,   16,   18,  204,
       88,   17,   20,   19,   43,   41,   19,   35,   16,   39,
       20,   16,   14,   14,  150,   19,   36,   17,   23,   20,
       18,   20,   21,   16,   18,   20,   23,   17,   11,   23,
       21,   21,   19,   35,   16,   24,   25,   16,   24,  180,
      150,   19,   17,   24,   25,   20,   22,   20,   21,   10,
       27,   20,   26,   25,   22,   23,    9,   21,   27,   22,
       26,   26,   29,   30,   27,  180,   28,   22,   31,   51,
       29,   30,   27,   21,   28,   29,   31,   51,    7,   25,
       33,   31,   28,   28,    5,   22,   30,   26,   33,   28,

       27,   32,   30,   22,   47,   47,   33,   34,   27,   32,
        4,   29,    3,   52,   32,   34,   54,   31,   28,   28,
       34,   52,   30,   54,   54,   28,    0,   30,    0,    0,
       47,   47,   33,   45,   45,   45,   45,   45,   45,   45,
       32,   48,   48,    0,    0,    0,   34,   46,   46,   46,
       46,   46,   46,   46,   46,   46,   58,   62,   76,   46,
       46,    0,    0,    0,   58,   62,   76,   48,   48,   50,
       50,   50,   50,   50,   50,   50,  102,   62,    0,    0,
        0,    0,   58,    0,  102,   46,   46,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   60,   63,    0,   49,

       49,   55,    0,   62,   60,   63,   59,   58,   57,   55,
       56,    0,   55,  112,   59,   59,   57,   63,   56,   56,
        0,  112,    0,    0,   60,   49,   49,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   55,   56,
       57,   59,   61,   63,    0,   56,   64,   66,   67,   60,
       61,    0,   61,   65,   64,   66,   67,   61,   65,   65,
        0,   65,   68,    0,   56,   57,   64,    0,   67,   69,
       68,   71,   70,   66,    0,   68,   74,   69,   61,   71,
       70,  221,   73,   61,   74,   72,   72,   77,   75,   69,
       73,   74,   64,   72,   67,   77,   75,   71,   66,   70,

       78,   68,   75,   82,   73,    0,   79,  221,   78,    0,
       81,   82,    0,   80,   79,   69,    0,   74,   81,    0,
       77,   80,   71,   79,   70,   80,   79,   82,   75,   83,
       73,    0,   78,   84,   86,  111,  111,   83,   85,   81,
      117,   84,   86,    0,  111,   77,   85,    0,  117,   79,
       98,   80,   79,   82,   86,   85,   98,   78,   98,   84,
        0,   83,   92,   92,   81,   92,   92,   92,   92,   92,
       92,   92,   95,   95,   95,   95,   95,   95,   95,   95,
       86,   85,    0,    0,   84,    0,   83,   94,   94,    0,
       94,   94,   94,   94,   94,   94,   94,   96,   96,   96,

       96,   96,   96,   96,   97,   97,   97,   97,   97,   97,
       97,   97,   97,   99,  100,  101,  103,    0,  104,    0,
        0,   99,  100,  101,  103,  100,  104,  103,  101,  105,
      106,  107,   99,  108,    0,  109,  110,  105,  106,  107,
      104,  108,  105,  109,  110,    0,    0,    0,  113,  110,
      108,  100,  109,  103,  101,  114,  113,  107,   99,  106,
        0,    0,  116,  114,  114,  118,  104,    0,  105,  113,
      116,    0,  115,  118,    0,  110,  108,    0,  109,  116,
      115,    0,  107,  120,  106,  115,  119,  119,    0,  121,
      114,  120,  118,  122,  119,  113,  120,  121,  123,  124,

        0,  122,  121,    0,    0,  116,  123,  124,  125,    0,
      126,  115,  124,  127,    0,  128,  125,  118,  126,  129,
        0,  127,  120,  128,    0,  123,  130,  129,  121,  132,
      125,  133,  129,    0,  130,    0,  131,  132,  124,  133,
      139,  128,    0,  126,  131,  138,  138,    0,  139,    0,
      123,  133,  141,  138,  130,  139,  125,  132,  129,  143,
      141,    0,    0,  131,    0,    0,  128,  143,  126,  134,
      134,  134,  134,  134,  134,  134,  144,  133,  155,  130,
        0,  139,  132,    0,  144,    0,  155,    0,  131,  135,
      135,  135,  135,  135,  135,  135,  136,  136,  136,  136,

      136,  136,  136,  137,  137,  137,  137,  137,  137,  137,
      137,  140,  142,  145,  146,  147,  148,    0,    0,  140,
      142,  145,  146,  147,  148,  149,  151,  146,  145,    0,
      140,    0,  142,  149,  151,  151,  154,  152,  153,  147,
      148,  156,  156,  157,  154,  152,  153,  149,  152,  156,
        0,  157,    0,  146,  145,  158,  140,    0,  142,  154,
      153,  151,  159,  158,  160,  147,  148,  161,  162,    0,
      159,    0,  160,  149,  152,  161,  162,  158,    0,  159,
      163,  164,  165,  162,  160,  154,  153,    0,  163,  164,
      165,  163,    0,  168,  166,  161,  171,    0,  173,    0,

      167,  168,  166,  158,  171,  159,  173,  164,  167,  162,
      160,  166,    0,  167,    0,    0,  168,  163,    0,    0,
      161,  169,  169,  169,  169,  169,  169,  169,  172,    0,
      175,    0,  164,  177,    0,    0,  172,  166,  175,  167,
        0,  177,  168,  170,  170,  170,  170,  170,  170,  170,
      170,  174,  176,    0,  172,  178,    0,    0,  179,  174,
      176,  177,  183,  178,  174,  176,  179,  179,  181,  182,
      183,    0,  184,  185,    0,  186,  181,  182,    0,  172,
      184,  185,  178,  186,    0,  184,  177,  187,    0,    0,
      174,  176,  188,  179,  189,  187,  181,  182,  187,    0,

      188,  191,  189,  186,  190,  192,    0,  178,  193,  191,
      194,  184,  190,  192,  191,  199,  193,  195,  194,  188,
      192,  181,  182,  199,  187,  195,    0,  190,  186,    0,
        0,  193,  196,  196,  196,  196,  196,  196,  196,  201,
      191,  200,  198,  205,  188,    0,  192,  201,  195,  200,
      198,  205,    0,  190,    0,    0,  201,  193,  197,  197,
      197,  197,  197,  197,  197,  198,  202,  203,  200,  206,
      207,    0,  210,  195,  202,  203,  208,  206,  207,  202,
      210,  207,  201,    0,  208,  208,  206,  209,  203,  212,
      213,  198,  215,  200,  211,  209,  209,  212,  213,  213,

      215,  214,  211,    0,    0,  202,    0,  207,    0,  214,
      216,  208,  206,  217,  203,    0,  211,    0,  216,  218,
      219,  217,  209,  214,  220,  213,  223,  218,  219,    0,
      218,    0,  220,  222,  223,  224,    0,  220,    0,  216,
      225,  222,  211,  224,  222,  226,  223,  227,  225,  214,
      228,  229,    0,  226,  230,  227,  218,  231,  228,  229,
      225,  233,  230,  220,  216,  231,  234,  227,  235,  233,
      222,  236,  223,  229,  234,    0,  235,  237,    0,  236,
      236,    0,  240,  234,  238,  237,  225,  239,  241,  237,
      240,    0,  238,  227,  242,  239,  241,  243,  239,  229,

        0,    0,  242,  244,  247,  243,  236,    0,  238,  234,
        0,  244,  247,  248,  243,  237,  241,  245,  246,    0,
      244,  248,  242,    0,  239,  245,  246,    0,  245,  246,
        0,    0,    0,    0,  238,    0,    0,    0,    0,    0,
      243,  241,    0,    0,    0,    0,  244,  242,    0,    0,
        0,    0,    0,    0,  245,  246,  250,  250,  250,  250,
      251,    0,  251,  251,  252,    0,  252,  252,  253,  253,
      254,    0,  254,  254,  255,    0,  255,  255,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,

      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      249,  249,  249,  249,  249,  249,  249,  249
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "tnglex.L"
/* Copyright (C) 1999-2015
 * Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 * For conditions of distribution and use, see copyright notice in "copyright"
 */
#line 12 "tnglex.L"
  #include <stdio.h>
  #include <stdlib.h>
  #include <string.h>

  #include "util.h"
  #include "tngparser.H"

  extern YYSTYPE* tnglval;
  extern tngFlexLexer* tnglexx;

/* rules */
#line 781 "tnglex.C"

#define INITIAL 0
#define DISCARD 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
#define ECHO LexerOutput( yytext, yyleng )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
\
	if ( (result = LexerInput( (char *) buf, max_size )) < 0 ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) LexerError( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
#define YY_DECL int yyFlexLexer::yylex()
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 30 "tnglex.L"


#line 885 "tnglex.C"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = & std::cin;

		if ( ! yyout )
			yyout = & std::cout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 250 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 249 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 32 "tnglex.L"
{ // special case-- #\n
		  BEGIN INITIAL;
		  yyless(0);             // put back the terminator
		  strcpy(tnglval->str,""); // feed a blank string
		  return STRING;
		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 39 "tnglex.L"
{  // Discard reset of line
		  BEGIN INITIAL;
		  int ll = yyleng <(TNGBUFSIZE-1) ? yyleng:(TNGBUFSIZE-1);
		  strncpy(tnglval->str,yytext,ll);
	          tnglval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 47 "tnglex.L"
{return B1950_;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 48 "tnglex.L"
{return BACKGROUND_;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 49 "tnglex.L"
{return BOX_;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 50 "tnglex.L"
{return BLACK_;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 51 "tnglex.L"
{return BLUE_;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 52 "tnglex.L"
{return CIRCLE_;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 53 "tnglex.L"
{return CYAN_;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 54 "tnglex.L"
{return DATE_;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 55 "tnglex.L"
{return DEBUG_;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 56 "tnglex.L"
{return DEGREES_;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 57 "tnglex.L"
{return ELLIPSE_;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 58 "tnglex.L"
{return ECLIPTIC_;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 59 "tnglex.L"
{return FILENAME_;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 60 "tnglex.L"
{return FK4_;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 61 "tnglex.L"
{return FK4_NO_E_;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 62 "tnglex.L"
{return FK5_;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 63 "tnglex.L"
{return FORMAT_;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 64 "tnglex.L"
{return GALACTIC_;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 65 "tnglex.L"
{return GREEN_;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 66 "tnglex.L"
{return HELIOECLIPTIC_;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 67 "tnglex.L"
{return HMS_;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 68 "tnglex.L"
{return ICRS_;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 69 "tnglex.L"
{return J2000_;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 70 "tnglex.L"
{return LINE_;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 71 "tnglex.L"
{return MAGENTA_;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 72 "tnglex.L"
{return OFF_;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 73 "tnglex.L"
{return ON_;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 74 "tnglex.L"
{return PHYSICAL_;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 75 "tnglex.L"
{return PIXELS_;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 76 "tnglex.L"
{return POINT_;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 77 "tnglex.L"
{return POLYGON_;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 78 "tnglex.L"
{return RED_;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 79 "tnglex.L"
{return SOURCE_;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 80 "tnglex.L"
{return SUPERGALACTIC_;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 81 "tnglex.L"
{return TEXT_;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 82 "tnglex.L"
{return VERSION_;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 83 "tnglex.L"
{return WHITE_;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 84 "tnglex.L"
{return YELLOW_;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 86 "tnglex.L"
{ // Integer
		  tnglval->integer = atoi(yytext);
		  return INT;
		}
	YY_BREAK
case 42:
#line 92 "tnglex.L"
case 43:
YY_RULE_SETUP
#line 92 "tnglex.L"
{ // Real Number
		  tnglval->real = atof(yytext);
		  return REAL;
		}
	YY_BREAK
case 44:
#line 98 "tnglex.L"
case 45:
YY_RULE_SETUP
#line 98 "tnglex.L"
{ // degrees
		  yytext[yyleng-1] = '\0';
		  tnglval->real = atof(yytext);
		  return ANGDEGREE;
		}	
	YY_BREAK
case 46:
#line 105 "tnglex.L"
case 47:
YY_RULE_SETUP
#line 105 "tnglex.L"
{ // Sexagesimal
		  int ll = yyleng <(TNGBUFSIZE-1)?yyleng:(TNGBUFSIZE-1);
		  strncpy(tnglval->str,yytext,ll);
	          tnglval->str[ll] = '\0';
		  return SEXSTR;
		}
	YY_BREAK
case 48:
#line 113 "tnglex.L"
case 49:
YY_RULE_SETUP
#line 113 "tnglex.L"
{ // Quoted String
		  int ll = (yyleng-2)<(TNGBUFSIZE-1)?(yyleng-2):(TNGBUFSIZE-1);
		  strncpy(tnglval->str,yytext+1,yyleng-2); // skip the " " 
	          tnglval->str[ll] = '\0'; // Remove the '"' 
		  return STRING;
		}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 120 "tnglex.L"
{ // Quoted String
		  int ll = (yyleng-2)<(TNGBUFSIZE-1)?(yyleng-2):(TNGBUFSIZE-1);
		  strncpy(tnglval->str,yytext+1,yyleng-2); // skip the '{'
	          tnglval->str[ll] = '\0'; // Remove the '}'
		  return STRING;
		}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 127 "tnglex.L"
{ // General String
		  int ll = yyleng <(TNGBUFSIZE-1) ? yyleng:(TNGBUFSIZE-1);
		  strncpy(tnglval->str,yytext,ll);
	          tnglval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 134 "tnglex.L"
{ // White Spaces
		} 
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 137 "tnglex.L"
{ // windows line feed
		  return '\n';
		}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 141 "tnglex.L"
{ // fake line feed
		  return '\n';
		}
	YY_BREAK
case 55:
/* rule 55 can match eol */
YY_RULE_SETUP
#line 145 "tnglex.L"
{ // linefeed
		  return '\n';
		}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(DISCARD):
#line 149 "tnglex.L"
{ // eof
		  return EOF_;
		}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 153 "tnglex.L"
{ // Else, return the char
		  return yytext[0];
		}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 157 "tnglex.L"
ECHO;
	YY_BREAK
#line 1297 "tnglex.C"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::yyFlexLexer( std::istream* arg_yyin, std::ostream* arg_yyout )
{
	yyin = arg_yyin;
	yyout = arg_yyout;
	yy_c_buf_p = 0;
	yy_init = 0;
	yy_start = 0;
	yy_flex_debug = 0;
	yylineno = 1;	// this will only get updated if %option yylineno

	yy_did_buffer_switch_on_eof = 0;

	yy_looking_for_trail_begin = 0;
	yy_more_flag = 0;
	yy_more_len = 0;
	yy_more_offset = yy_prev_more_offset = 0;

	yy_start_stack_ptr = yy_start_stack_depth = 0;
	yy_start_stack = NULL;

	yy_buffer_stack = 0;
	yy_buffer_stack_top = 0;
	yy_buffer_stack_max = 0;

	yy_state_buf = 0;

}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::~yyFlexLexer()
{
	delete [] yy_state_buf;
	tngfree(yy_start_stack  );
	yy_delete_buffer( YY_CURRENT_BUFFER );
	tngfree(yy_buffer_stack  );
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream* new_in, std::ostream* new_out )
{
	if ( new_in )
		{
		yy_delete_buffer( YY_CURRENT_BUFFER );
		yy_switch_to_buffer( yy_create_buffer( new_in, YY_BUF_SIZE  ) );
		}

	if ( new_out )
		yyout = new_out;
}

#ifdef YY_INTERACTIVE
size_t yyFlexLexer::LexerInput( char* buf, size_t /* max_size */ )
#else
size_t yyFlexLexer::LexerInput( char* buf, size_t max_size )
#endif
{
	if ( yyin->eof() || yyin->fail() )
		return 0;

#ifdef YY_INTERACTIVE
	yyin->get( buf[0] );

	if ( yyin->eof() )
		return 0;

	if ( yyin->bad() )
		return -1;

	return 1;

#else
	(void) yyin->read( buf, max_size );

	if ( yyin->bad() )
		return -1;
	else
		return yyin->gcount();
#endif
}

void yyFlexLexer::LexerOutput( const char* buf, size_t size )
{
	(void) yyout->write( buf, size );
}

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
int yyFlexLexer::yy_get_next_buffer()
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					tngrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) tngrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    yy_state_type yyFlexLexer::yy_get_previous_state()
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 250 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    yy_state_type yyFlexLexer::yy_try_NUL_trans( yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 250 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 249);

	return yy_is_jam ? 0 : yy_current_state;
}

    void yyFlexLexer::yyunput( int c, register char* yy_bp)
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

    int yyFlexLexer::yyinput()
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyFlexLexer::yyrestart( std::istream* input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yyFlexLexer::yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

    void yyFlexLexer::yy_load_buffer_state()
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream* file, int size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) tngalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) tngalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yyFlexLexer::yy_delete_buffer( YY_BUFFER_STATE b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		tngfree((void *) b->yy_ch_buf  );

	tngfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    void yyFlexLexer::yy_init_buffer( YY_BUFFER_STATE b, std::istream* file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

	b->yy_is_interactive = 0;
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yyFlexLexer::yy_flush_buffer( YY_BUFFER_STATE b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yyFlexLexer::yypush_buffer_state (YY_BUFFER_STATE new_buffer)
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yyFlexLexer::yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
void yyFlexLexer::yyensure_buffer_stack(void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)tngalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)tngrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

    void yyFlexLexer::yy_push_state( int new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) tngalloc(new_size  );

		else
			(yy_start_stack) = (int *) tngrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    void yyFlexLexer::yy_pop_state()
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    int yyFlexLexer::yy_top_state()
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

void yyFlexLexer::LexerError( yyconst char msg[] )
{
    	std::cerr << msg << std::endl;
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *tngalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *tngrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void tngfree (void * ptr )
{
	free( (char *) ptr );	/* see tngrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 157 "tnglex.L"



void tngDiscard(int doit)
{
  if (tnglexx)
    tnglexx->begin(DISCARD, doit);
}

void tngFlexLexer::begin(int which, int doit)
{
  BEGIN which;
  if (doit)
    yyless(0);
}

